#define F_CPU 16000000UL	// Define CPU Frequency()16MHz
#include <avr/io.h>			// Include AVR std. library file
#include <stdio.h>			// Include std. library file
#include <util/delay.h>		// Include Delay header file
        
void ADC_Init()				// ADC Initialization function
{
	DDRC=0x00;				// Make ADC port as input
	ADCSRA = 0x87;			// Enable ADC, with freq/128
	ADMUX = 0x40;			// Vref: Avcc, ADC channel: 0
}

int ADC_Read(char channel)
{
	ADMUX = 0x40 | (channel & 0x07);	// set input channel to read
	ADCSRA |= (1<<ADSC);				// Start ADC conversion 
	while (!(ADCSRA & (1<<ADIF)));
			/* Wait until end of conversion by polling ADC interrupt flag*/
	ADCSRA |= (1<<ADIF);				// Clear interrupt flag
	_delay_ms(1);						// Wait a little bit 
	return ADCW;						// Return ADC word
}
              
int main(void)
{
  ADC_Init();						// ADC initialize function
  DDRB|=(1<<PB1)|(1<<PB2);			// Make OC1A and OC1B pin as output
  TCNT1 = 0;						// Set timer1 count zero
  ICR1 = 4999;						// Set TOP count for timer1 in ICR1 register //50Hz for 20ms pulse width

	/* Set Fast PWM, TOP in ICR1, Clear OC1A, OC1B on compare match, clk/64 */
  TCCR1A = (1<<WGM11)|(1<<COM1A1)|(1<<COM1B1);
  TCCR1B = (1<<WGM12)|(1<<WGM13)|(1<<CS10)|(1<<CS11);
  
  int c_X = 90 + 512/2; // The value of the initial position
  int c_Y = 90 + 512/2;	// The value of the initial position

  int ADC_ValueX; 
  int ADC_ValueY;
  
  OCR1A = c_X;			// motor to the initial position
  OCR1B = c_Y;			// motor to the initial position
  
  while(1)
  {
	 ADC_ValueX = ADC_Read(0);	// reading the value from the joystick
	 ADC_ValueY = ADC_Read(1);	// reading the value from the joystick
	 
	 if(ADC_ValueX >= 715)				// when the joystick is tilted from its initial position	
	 {
		c_X = c_X +5;					// changing the position value
		if(c_X >=600)	{c_X = 600;}	// to stay in the range of 90 - 600
		if(c_X <=90)	{c_X = 90;}		// to stay in the range of 90 - 600
	 }
	 if(ADC_ValueX <= 310)
	 {
		c_X = c_X -5;
		if(c_X >=600)	{c_X = 600;}
		if(c_X <=90)	{c_X = 90;}
	 }
	 if(ADC_ValueY >= 715)
	 {
		c_Y = c_Y +5;
		if(c_Y >=600)	{c_Y = 600;}
		if(c_Y <=90)	{c_Y = 90;}
	 }
     if(ADC_ValueY <= 310)
	 {
		c_Y = c_Y -5;
		if(c_Y >=600)	{c_Y = 600;}
		if(c_Y <=90)	{c_Y = 90;}
	 } 
	 OCR1A = c_X;		// setting the motor to a new value
	 OCR1B = c_Y;		// setting the motor to a new value
	 _delay_ms(16);		// wait a bit
  }
  return(0);
}
